/*
 *    GsdlCollage Services java file
 *    Copyright (C) 2002 New Zealand Digital Library, http://www.nzdl.org
 *
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.greenstone.gsdl3.service;

import org.greenstone.gsdl3.util.*;

import org.greenstone.mgpp.*;
import org.w3c.dom.Document;
import org.w3c.dom.Node;
import org.w3c.dom.Element;
import org.w3c.dom.Text;

import java.util.Vector;
import java.util.HashMap;
import java.io.File;
import java.io.Serializable;

import org.apache.log4j.*;

/**
 * GsdlCollageServices - the gsdl collage browsing service
 *
 */
public class GsdlCollageBrowse
  extends ServiceRack {
  
  static Logger logger = Logger.getLogger(org.greenstone.gsdl3.service.GsdlCollageBrowse.class.getName());
  
  // the services on offer
  private static final String GSDL_COLLAGE_SERVICE = "GsdlCollageApplet";
  
  private String basepath = null;
  
  private Element applet_description = null;
  
  public GsdlCollageBrowse() {
      super();
  }
  
  public void cleanUp() {
    super.cleanUp();
    
  }
  
  /** configure the service module
   *
   * @param info a DOM Element containing any config info for the service
   * @return true if configured
   */
  public boolean configure(Element info, Element extra_info) {
    
    if (!super.configure(info, extra_info)){
      return false;
    }
    
    logger.info("configuring GsdlCollageBrowse");
    
    // set up short_service_info_ - for now just has name and type
    Element e = this.desc_doc.createElement(GSXML.SERVICE_ELEM);
    e.setAttribute(GSXML.TYPE_ATT, GSXML.SERVICE_TYPE_APPLET);
    e.setAttribute(GSXML.NAME_ATT, GSDL_COLLAGE_SERVICE);
    this.short_service_info.appendChild(e);
    
    // set up the static applet description
    
    applet_description = this.desc_doc.createElement(GSXML.SERVICE_ELEM);
    applet_description.setAttribute(GSXML.TYPE_ATT, GSXML.SERVICE_TYPE_APPLET);
    applet_description.setAttribute(GSXML.NAME_ATT, GSDL_COLLAGE_SERVICE);
    
    // add in the applet info for the gsdl collage applet
    // need to make this dynamic - library names etc
    // change the applet params - have a single param with the library name
    // this is left blank at this end, and must be filled in by applet action - if the library name is not needed, this param is left out

    String siteName = this.site_home.substring(this.site_home.lastIndexOf("/sites/")+"/sites/".length());
    
    String app_info = "<"+GSXML.APPLET_ELEM+" CODEBASE='applet' CODE='org.greenstone.applet.GsdlCollageApplet.GsdlCollageApplet.class' ARCHIVE='GsdlCollageApplet.jar' WIDTH='600' HEIGHT='300'>"; // w=645,h=780
    app_info +="<param name='library' value='" + this.library_name + "'/>";
    app_info +="<param name='collection'   value='" + this.cluster_name + "'/>";
    app_info += "<param name='gsdlversion' value='3' />";
    app_info += "<param name='baseurl' value='http://localhost:8383/greenstone3/' />";
    //app_info += "<param name='sitename' value='"+ this.site_home +"' />\n";
    //app_info += "<param name='hrefMustHave' value='smallbea' />\n";
    app_info += "<param name='hrefMustHave' value='" + this.library_name + "/sites/" + siteName + "/collect/" + this.cluster_name + "'/>\n";
    //app_info += "<param name='gwcgi' value='http://localhost:8383/greenstone3/library' /><param name='classifier' value='CL3.1' /><param name='hrefMustHave' value='CL3' /><param name='imageMustNotHave' value='hl=%x=%gt=%gc=%.pr' /><param name='imageType' value='.jpg%%.png' /><param name='maxDepth' value='500' /><param name='maxDisplay' value='25' /><param name='refreshDelay' value='1500' /><param name='isJava2' value='auto' /><param name='bgcolor' value='#96c29a' />The Collage Applet.</"+GSXML.APPLET_ELEM+">"; // TODO

    //app_info += "<param name='documentroot' value='library/collection/" + this.cluster_name + "/'/>";
    app_info += "<param name='documentroot' value='greenstone3'/>\n"; // TODO
    app_info += "<param name='verbosity' value='3' />\n";
    app_info += "<param name='imageType' value='.jpg%.png' />\n";
    app_info += "<param name='imageMustNotHave' value='interfaces/' />\n";
    app_info += "<param name='classifier' value='CL2.3' /><param name='maxDepth' value='500' /><param name='maxDisplay' value='25' /><param name='refreshDelay' value='1500' /><param name='isJava2' value='auto' /><param name='bgcolor' value='#96c29a' />The Collage Applet.</"+GSXML.APPLET_ELEM+">"; // TODO
    
    Document dom = this.converter.getDOM(app_info);
    if (dom==null) {
      logger.error("Couldn't parse applet info");
      return false;
    }
    Element app_elem = dom.getDocumentElement();
    applet_description.appendChild(this.desc_doc.importNode(app_elem, true));
    
    return true;
  }
  
  protected Element getServiceDescription(Document doc, String service, String lang, String subset) {
    if (!service.equals(GSDL_COLLAGE_SERVICE)) {
      return null;
    }
    Element describe = (Element)doc.importNode(applet_description,true);
	
    Element el1 = GSXML.createDisplayTextElement(doc, GSXML.DISPLAY_TEXT_NAME,  getTextString(GSDL_COLLAGE_SERVICE+".name", lang));	
    describe.appendChild(el1);
    
    Element el2 = GSXML.createDisplayTextElement(doc, GSXML.DISPLAY_TEXT_DESCRIPTION,  getTextString(GSDL_COLLAGE_SERVICE+".description", lang));
    describe.appendChild(el2);
	
    return describe;
  }
  
  protected Element processGsdlCollageApplet(Element request) {
    Document result_doc = XMLConverter.newDOM();
  
    // the result element
    Element result = result_doc.createElement(GSXML.RESPONSE_ELEM);
    result.setAttribute(GSXML.FROM_ATT, GSDL_COLLAGE_SERVICE);
    result.setAttribute(GSXML.TYPE_ATT, GSXML.REQUEST_TYPE_PROCESS);
    
    // applet result info must be in appletInfo element
    Element applet_data = result_doc.createElement(GSXML.APPLET_DATA_ELEM);
    result.appendChild(applet_data);
    Element gsdlCollage_data = result_doc.createElement("gsdlCollageData");
    applet_data.appendChild(gsdlCollage_data);
    
    gsdlCollage_data.appendChild(result_doc.createTextNode("TODO: GsdlCollage applet doesn't actually do any processing"));
    
    return result;
    
    
  }// processGsdlCollageApplet
    
  protected Element gsdlCollageError(Document collage_doc, String message) {
    Element e = collage_doc.createElement("gsdlCollageError");
    Text t = collage_doc.createTextNode(message);
    e.appendChild(t);
    return e;
  }
  
}

